LineValues

Struct LineValues 

#[repr(C)]
pub struct LineValues(pub [u8; 64]);
The logical values of the requested lines.

Values are stored as u8, as that is what the uAPI specifies.

0 is inactive with 1 and all other values taken as active.

Values are stored in the same order as the offsets in the HandleRequest.offsets.

Values for input lines are ignored.

Tuple Fields

0: [u8; 64]

Implementations

Source

impl LineValues

pub fn from_slice(s: &[u8]) -> Self

Create values from a slice.

The values are in the same order as HandleRequest.offsets.

pub fn copy_from_slice(&mut self, s: &[u8])

Copy values from an iterable list - in order of requested offsets.

pub fn get(&self, idx: usize) -> u8

Return the value of a line.

Note that the LineValues need to be populated via a call to get_line_values to get values from the underlying hardware.

pub fn set(&mut self, idx: usize, value: u8)

Set the value of a line.

Note that this is not applied to hardware until these values are passed to set_line_values.

  • idx - The index into the HandleRequest.offsets for the line of interest.
  • value - The logical state of the line to be set.