#[repr(C)]pub struct LineConfigAttribute {
pub attr: LineAttribute,
pub mask: u64,
}Expand description
A configuration attribute associated with one or more of the requested lines.
Fields
attr: LineAttributeThe configurable attribute.
mask: u64The lines to which the attribute applies, with each bit number corresponding
to the index into LineRequest.offsets.