LineEdgeEvent

Struct LineEdgeEvent 

pub struct LineEdgeEvent {
    pub timestamp_ns: u64,
    pub kind: u32,
    pub offset: Offset,
    pub seqno: u32,
    pub line_seqno: u32,
    /* private fields */
}
Information about an edge event on a requested line.

Fields

timestamp_ns: u64

The best estimate of time of event occurrence, in nanoseconds.

By default the timestamp is read from CLOCK_MONOTONIC and is intended to allow the accurate measurement of the time between events. It does not provide the wall-clock time.

If the LineFlags::EVENT_CLOCK_REALTIME flag is set then the timestamp is read from CLOCK_REALTIME.

kind: u32

The event trigger identifier (LineEdgeEventKind)

offset: Offset

The offset of the line that triggered the event.

seqno: u32

The sequence number for this event in the sequence of events for all the lines in this line request.

line_seqno: u32

The sequence number for this event in the sequence of events on this particular line.

Implementations

Source

impl LineEdgeEvent

pub fn from_slice(d: &[u64]) -> Result<&LineEdgeEvent>

Read an edge event from a buffer.

The buffer is assumed to have been populated by a read of the line request File, so the content is initialised.

pub fn u64_size() -> usize

The number of u64 words required to store a LineEdgeEvent.