LineInfoChangeEvent

Struct LineInfoChangeEvent 

pub struct LineInfoChangeEvent {
    pub info: LineInfo,
    pub timestamp_ns: u64,
    pub kind: u32,
    /* private fields */
}
An event indicating a change to the info for a line.

Fields

info: LineInfo

The new line info.

timestamp_ns: u64

The best estimate of time of event occurrence, in nanoseconds.

kind: u32

The trigger for the change (LineInfoChangeKind)

Implementations

Source

impl LineInfoChangeEvent

pub fn from_slice(d: &[u64]) -> Result<&LineInfoChangeEvent>

Read an info change event from a buffer.

The buffer is assumed to have been populated by a read of the chip File, so the content is initialised.

pub fn u64_size() -> usize

The number of u64 words required to store a LineInfoChangeEvent.