Struct gpiocdev_uapi::v2::LineEdgeEvent
source · [−]#[repr(C)]pub struct LineEdgeEvent {
pub timestamp_ns: u64,
pub kind: LineEdgeEventKind,
pub offset: Offset,
pub seqno: u32,
pub line_seqno: u32,
/* private fields */
}Expand description
Information about an edge event on a requested line.
Fields
timestamp_ns: u64The best estimate of time of event occurrence, in nanoseconds.
By default the timestamp is read from CLOCK_MONOTONIC and is intended to allow the accurate measurement of the time between events. It does not provide the wall-clock time.
If the LineFlags::EVENT_CLOCK_REALTIME flag is set then the
timestamp is read from CLOCK_REALTIME.
kind: LineEdgeEventKindThe event trigger identifier.
offset: OffsetThe offset of the line that triggered the event.
seqno: u32The sequence number for this event in the sequence of events for all the lines in this line request.
line_seqno: u32The sequence number for this event in the sequence of events on this particular line.
Implementations
sourceimpl LineEdgeEvent
impl LineEdgeEvent
sourcepub fn from_buf(d: &[u8]) -> Result<&LineEdgeEvent>
pub fn from_buf(d: &[u8]) -> Result<&LineEdgeEvent>
Read an edge event from a buffer.